/*
 * Copyright 2022-2023 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package xyz.zhouxy.plusone.constant;

import java.util.Collection;

import javax.annotation.Nonnull;

import xyz.zhouxy.plusone.commons.util.Enumeration;

/**
 * 实体状态
 *
 * @author <a href="https://gitee.com/zhouxy108">ZhouXY</a>
 */
public final class EntityStatus extends Enumeration<EntityStatus> {

    private EntityStatus(int id, @Nonnull String name) {
        super(id, name);
    }

    // 常量
    public static final EntityStatus AVAILABLE = new EntityStatus(0, "正常");
    public static final EntityStatus DISABLED = new EntityStatus(1, "禁用");

    private static final ValueSet<EntityStatus> VALUE_SET = new ValueSet<>(
            AVAILABLE, DISABLED);

    @Nonnull
    public static EntityStatus of(int id) {
        return VALUE_SET.get(id);
    }

    @Nonnull
    public static Collection<EntityStatus> constants() {
        return VALUE_SET.getValues();
    }
}
